/**
 * This file contains the listener function that will be assigned to the
 * corpus_analysis ResultsView. The listener is listening for the notification
 * event which is being dispatched by the corpus_analysis Client. The
 * notification Event triggers the listener whiche will call different
 * callback functions depending on the detail information of the notification
 * event.
 */

import {
  connectingCallback,
  connectedCallback,
  connectingFaildeCallback,
  queryDataPreparingCallback,
  queryDataRecievingCallback,
  queryDataRecievedCallback,
} from './callbacks.js';

function recieveNotification(eventType, resultsList) {
  document.addEventListener(eventType, (event) => {
    let caseIdentifier = event.detail.caseIdentifier;
    switch (caseIdentifier) {
      case 'connecting':
        console.info('Recieved notification:', caseIdentifier);
        connectingCallback(resultsList, event.detail);
        // execute callback
        break;
      case 'connected':
        console.info('Recieved notification:', caseIdentifier);
        connectedCallback(resultsList, event.detail);
        break;
      case 'connecting-failed':
        console.info('Recieved notification:', caseIdentifier);
        // execute callback
        connectingFaildeCallback(resultsList, event.detail);
        break;
      case 'query-data-prepareing':
        console.info('Recieved notification:', caseIdentifier);
        // execute callback
        queryDataPreparingCallback(resultsList, event.detail);
        break;
      case 'query-data-recieving':
        console.info('Recieved notification:', caseIdentifier);
        // execute callback
        queryDataRecievingCallback(resultsList, event.detail);
        break;
      case 'query-data-recieved':
        console.info('Recieved notification:', caseIdentifier);
        // execute callback
        queryDataRecievedCallback(resultsList, event.detail);
        break;
      default:
        console.error('Recieved unkown notification case identifier');
        // do something to not crash the analysis session?
        // maybe unnecessary
    }
  });
}

// export listeners
export { recieveNotification };